@@ -1,35 +1,20 @@
-# -*-mode: tcl; fill-column: 75; tab-width: 8; coding: iso-latin-1-unix -*-
-#
-#       $Id: Browser.tcl,v 1.25 2011-03-21 09:18:58 villate Exp $
-#
-###### Browser.tcl ######
 ############################################################
-# Netmath       Copyright (C) 1998 William F. Schelter     #
-# For distribution under GNU public License.  See COPYING. #
-############################################################
-
-## source keyb.tcl
-
-###### keyb.tcl ######
-############################################################
-# Netmath       Copyright (C) 1998 William F. Schelter     #
+# Browser.tcl                                              #
+# Copyright (C) 1998 William F. Schelter                   #
 # For distribution under GNU public License.  See COPYING. #
+#                                                          #
+#     Modified by Jaime E. Villate                         #
 ############################################################
 
 proc peekLastCommand {win} {
-    global maxima_priv
-    if { [info exists maxima_priv(lastcom,$win)] } {
-	return $maxima_priv(lastcom,$win)
+    if { [info exists ::xmaxima_priv(lastcom,$win)] } {
+	return $::xmaxima_priv(lastcom,$win)
     }
 }
 
 proc pushCommand { win command arglist } {
-    global maxima_priv
-    set maxima_priv(lastcom,$win) [list $command $arglist]
+    set ::xmaxima_priv(lastcom,$win) [list $command $arglist]
 }
-
-
-
 #
 #-----------------------------------------------------------------
 #
@@ -44,9 +29,7 @@ proc pushCommand { win command arglist } {
 #
 #----------------------------------------------------------------
 #
-
 proc tkTextInsert { w s } {
-    global maxima_priv
     set after [$w tag names insert]
     set before [$w tag names "insert-1char"]
     set both [intersect $after $before]
@@ -54,13 +37,13 @@ proc tkTextInsert { w s } {
     # puts "before=$before"
 
     foreach v [concat $after $before] {
-	if { [regexp -- $maxima_priv(sticky) $v] } {
+	if { [regexp -- $::xmaxima_priv(sticky) $v] } {
 	    lappend both $v
 	}
     }
 
-    if { [info exists maxima_priv($w,inputTag) ] } {
-	lappend both $maxima_priv($w,inputTag)
+    if { [info exists ::xmaxima_priv($w,inputTag) ] } {
+	lappend both $::xmaxima_priv($w,inputTag)
     }
 
     if {($s == "") || ([$w cget -state] == "disabled")} {
@@ -74,8 +57,8 @@ proc tkTextInsert { w s } {
     }
     $w insert insert $s $both
     $w see insert
-
 }
+
 proc getRange { win a b }  {
     if { [$win compare $a < $b ] } {
 	return "$a $b" 
@@ -83,8 +66,6 @@ proc getRange { win a b }  {
 	return "$b $a"
     }
 }
-
-
 #
 #-----------------------------------------------------------------
 #
@@ -131,11 +112,8 @@ proc tagRanges { win tag begin end } {
 		}
 	    }
 	    return $answer
-	
 	}
 }
-
-
 #
 #-----------------------------------------------------------------
 #
@@ -165,10 +143,6 @@ proc thisRange { win tag index } {
     }
     return ""
 }
-
-
-
-
 #
 #-----------------------------------------------------------------
 #
@@ -187,18 +161,17 @@ proc thisRange { win tag index } {
 #----------------------------------------------------------------
 #
 proc insertRichText {win index list } {
-    global maxima_priv
-    set maxima_priv(currentwin) $win
-    set maxima_priv(point) $index
-    foreach v $maxima_priv(richTextCommands) {
-	set maxima_priv($v,richTextCommand) [llength [info args $v]]
+    set ::xmaxima_priv(currentwin) $win
+    set ::xmaxima_priv(point) $index
+    foreach v $::xmaxima_priv(richTextCommands) {
+	set ::xmaxima_priv($v,richTextCommand) [llength [info args $v]]
     }
     set i 0
     set ll [llength $list]
     while { $i < $ll } {
 	set com [lindex $list $i]
 	incr i
-	if { [catch { set n $maxima_priv($com,richTextCommand)} ] } {
+	if { [catch { set n $::xmaxima_priv($com,richTextCommand)} ] } {
 	    return -code error -errorinfo [concat [mc "illegal command in rich text:"] "$com"]
 	}
 	set form [concat $com [lrange $list $i [expr {$i +$n -1}]]]
@@ -208,24 +181,16 @@ proc insertRichText {win index list } {
 	incr i $n
     }
 }
-
-
 proc Tins { tags text } {
-    global maxima_priv
     # foreach v $args { append text $v }
-    $maxima_priv(currentwin) insert $maxima_priv(point) $text  $tags
+    $::xmaxima_priv(currentwin) insert $::xmaxima_priv(point) $text  $tags
 }
 
 proc TinsSlashEnd { tags text } {
-    global maxima_priv
     # foreach v $args { append text $v }
-    $maxima_priv(currentwin) insert $maxima_priv(point) "$text\\"  $tags
+    $::xmaxima_priv(currentwin) insert $::xmaxima_priv(point) "$text\\"  $tags
 }
 
-
-
-## endsource keyb.tcl
-
 proc underTop {top win} {
     if { "$top" == "." } {
 	return $win
@@ -234,50 +199,6 @@ proc underTop {top win} {
     }
 }
 
-# now unused
-proc showHistory { window } {
-    set top [winfo toplevel $window]
-    set win [omPanel $window]
-    makeLocal $win history historyIndex
-
-    set w [underTop $top .historylist]
-    if {[winfo exists $w]} {catch {destroy $w}}
-
-    frame $w -borderwidth 2 -relief raised
-    label $w.title -text [mc "History List"] -relief raised
-    pack $w.title -side top -fill x
-    setHelp $w.title [mc "This window may be dragged elsewhere by grabbing this title bar with the mouse.  Double clicking on a history item, moves to that page."]
-
-    button $w.dismiss -command "destroy $w" -text [mc "Close"]
-    pack $w.dismiss -side bottom -fill x
-    setHelp $w.dismiss [mc "Remove the history list"]
-
-    scrollbar $w.scrolly -command "$w.list yview"
-    scrollbar $w.scrollx -orient horizontal -command "$w.list xview"
-    pack $w.scrollx -side bottom -fill x -expand 1
-    pack $w.scrolly -side right -fill y -expand 1
-    listbox $w.list -yscroll "$w.scrolly set" \
-	-width 35 -height 16 -setgrid 1 -xscroll "$w.scrollx set"
-    $w.title configure -font [$w.list cget -font]
-    set l $w.list
-
-    pack $w.list  -side top -fill both -expand 1
-    resetHistory $win $w.list junk history
-    global [oarray $win]
-
-    #puts "    trace variable [oloc $win history] w {resetHistory $win $w.list}"
-    trace vdelete  [oloc $win history] w "resetHistory $win $w.list"
-    trace variable [oloc $win history] w "resetHistory $win $w.list"
-    trace vdelete [oloc $win historyIndex] w "resetHistory $win $w.list"
-    trace variable [oloc $win historyIndex] w "resetHistory $win $w.list"
-    bind $l <Double-1> {OpenMathMoveHistory [omPanel %W] [expr [%W index @%x,%y]-[oget [omPanel %W] historyIndex]]}
-    bind  $w.title <B1-Motion> "dragPlacedWindow $w %W %X %Y"
-    bind  $w.title <1> "startDragPlacedWindow $w %X %Y"
-    place $w -relx .4 -rely .8 -in $top
-
-
-}
-
 proc deleteAllTraces {var} {
     foreach v [uplevel "#0" trace vinfo $var] {
 	uplevel "#0" trace vdelete $var [lindex $v 0] [list [lindex $v 1]]
@@ -306,7 +227,6 @@ proc resetHistory { win list args } {
     }
 }
 
-
 proc startDragPlacedWindow { win x y } {
     oset $win placeinfo [list $x $y [place info $win]]
 }
@@ -351,9 +271,11 @@ proc toLocalFilename { url } {
 	    return [file join / [assoc dirname $url] [assoc filename $url] ]
 
 	}
-	default "unknown type: $type"
+        xmaxima {
+            return [assoc filename $url]
+        }
+	default {error "unknown type: $type"}
     }
-
 }
 
 proc OpenMathGetWindow { commandPanel win } {
@@ -387,16 +309,12 @@ proc filesplit { x } {
     return [list [join $dir /] $file]
 }
 
-
-
 proc decodeURL { name } {
     set server ""
     if { [regexp  {([^#]*)#(.*)$} $name junk name anchor] } {
 	lappend answer anchor $anchor
 	# puts "answer=$answer"
     }
-
-
     if { [regexp {^([a-z]+)[(]?([0-9]*)[)]?:/(.+)$} $name all type port path ] } {
 	lappend answer type $type
     } else {
@@ -469,7 +387,11 @@ proc encodeURL { lis } {
 	    #	   appendSeparate ans "" [assoc filename $lis ""] ""
 	    appendSeparate ans "#" [assoc anchor $lis ""] ""
 	}
-	default "error unsupported url type: $type"
+        xmaxima {
+            appendSeparate ans "" $type :/
+            append ans  [dirnamePlusFilename $lis]
+        }
+	default {error "unsupported url type: $type"}
     }
     return $ans
 }
@@ -519,8 +441,6 @@ proc resolveURL { name current {post ""} } {
 		lappend ans $key $val
 	    }
 	}
-	
-
     }
     if { "$post" != "" } {
 	set ans [putassoc post $ans $post]
@@ -529,28 +449,22 @@ proc resolveURL { name current {post ""} } {
 }
 
 proc getURLrequest { path server port types {post ""} {meth ""} } {
-    global maxima_priv
-
     if { "$meth" != "" } {
 	set method $meth 
     } else {
 	set method GET
 	if { "$post" != "" } {set method POST}
     }
-
     #puts "getURLrequest $path $server $port [list $types]"
-    foreach {v handler}  $maxima_priv(urlHandlers) {
+    foreach {v handler}  $::xmaxima_priv(urlHandlers) {
 	lappend types $v,
     }
-
     set ans "$method $path HTTP/1.0\nConnection: Keep-Alive\nUser-agent: netmath\nHost: $server:$port\nAccept: $types\n"
     if { "$post" != "" } {
 	# append ans "Content-length: [string length $post]\n\n$post"
 	append ans "Content-type: application/x-www-form-urlencoded\nContent-length: [string length $post]\n\n$post"
     }
-
     return $ans
-
 }
 
 proc canonicalizeContentType { type } {
@@ -559,38 +473,34 @@ proc canonicalizeContentType { type } {
 }
 
 proc getURL { resolved type {mimeheader ""} {post ""} } {
-    global maxima_priv
     set res $resolved
-
     set ans ""
     set method ""
     if { "$mimeheader" != ""} {
 	uplevel 1 set $mimeheader \[list\]
     }
     uplevel 1 set $type "unknown"
-
-
     #puts "getting $resolved,post=<$post>"
     switch [assoc type $res] {
 	http {
 	    #mike FIXME: replace with http get
 	    # puts $res
 	    # puts "socket [assoc server $res] [assoc port $res 80]"
-	    if { [info exists maxima_priv(proxy,http) ] } {
-		set sock [eval socket $maxima_priv(proxy,http)]
-		#		puts "opening proxy request socket $maxima_priv(proxy,http)"
+	    if { [info exists ::xmaxima_priv(proxy,http) ] } {
+		set sock [eval socket $::xmaxima_priv(proxy,http)]
+		#		puts "opening proxy request socket $::xmaxima_priv(proxy,http)"
 	    } else {
 		set server [assoc server $res]
 		set port [assoc port $res 80]
 		#mike FIXME - use async sockets and dns
 		if {[catch {socket $server $port} sock]} {
 		    global errorInfo
-		    tide_failure [M [mc "Error connecting to %s on %s\n%s"] \
+		    tk_messageBox -title Error -icon error -message \
+                        [mc "Error connecting to %s on %s\n%s" \
 				      $server $port $sock]
 		    return
 		}
 	    }
-	
 	    fconfigure $sock -blocking 0
 	    ##DO NOT DELETE THE FOLLOWING !!!!!puts!!!!!!!!
 	    #puts request=[getURLrequest [dirnamePlusFilename $res] [assoc server $res] [assoc port $res] image/gif $post]
@@ -605,20 +515,19 @@ proc getURL { resolved type {mimeheader ""} {post ""} } {
 		oset $sock cachename ""
 	    }
 	    flush $sock
-	    if { [readAllData $sock -tovar maxima_priv(url_result) \
-		      -translation binary -mimeheader maxima_priv(mimeheader)  \
+	    if { [readAllData $sock -tovar ::xmaxima_priv(url_result) \
+		      -translation binary -mimeheader ::xmaxima_priv(mimeheader)  \
 		      -timeout 120000 -chunksize 2024] > 0 } {
 		
-		#puts "length=[string length $maxima_priv(url_result)]"
+		#puts "length=[string length $::xmaxima_priv(url_result)]"
 		#	flush stdout
-		
-		set contentType [canonicalizeContentType [assoc content-type $maxima_priv(mimeheader) text/plain]]
+		set contentType [canonicalizeContentType [assoc content-type $::xmaxima_priv(mimeheader) text/plain]]
 		uplevel 1 set $type [list $contentType]
 		if { "$mimeheader" != "" } {
-		    uplevel 1 set $mimeheader \[ uplevel "#0" set maxima_priv(mimeheader) \]
+		    uplevel 1 set $mimeheader \[ uplevel "#0" set ::xmaxima_priv(mimeheader) \]
 		}
-		set ans $maxima_priv(url_result)
-		unset maxima_priv(url_result)
+		set ans $::xmaxima_priv(url_result)
+		unset ::xmaxima_priv(url_result)
 		return $ans
 	    } else {
 		return "had error"
@@ -626,7 +535,14 @@ proc getURL { resolved type {mimeheader ""} {post ""} } {
 	}
 	file {
 	    set name [toLocalFilename $res]
-	    set fi [open $name r]
+            if {[file isfile $name]} {
+                set fi [open $name r]
+            } else {
+                set answer "<h1>Error</h1>\n<p>File: $name not found.</p>"
+                set contentType text/html
+                uplevel 1 set $type $contentType
+                return $answer
+            }
 	    set answer [read $fi]
 	    if { [regexp -nocase {[.]html?$} $name ] || [regexp -nocase "^(\[ \n\t\r\])*<html>" $answer] } {
 		set contentType text/html
@@ -644,6 +560,12 @@ proc getURL { resolved type {mimeheader ""} {post ""} } {
 	    close $fi
 	    return $answer
 	}
+        xmaxima {
+            set answer $::xmaxima_priv(error)
+            set contentType text/html
+            uplevel 1 set $type $contentType
+            return $answer
+        }
 	default {
 	    #mike dirpath?
 	    error [concat [mc "not supported"] "[lindex $res 0]"]
@@ -651,30 +573,24 @@ proc getURL { resolved type {mimeheader ""} {post ""} } {
     }
 }
 
-
-
-
 proc getImage { resolved width height} {
-    global maxima_priv
     set res $resolved
     #puts [list getImage [list $resolved] $width $height]
     set ans ""
     catch {
-	if { "" != "[image type $maxima_priv(image,$res,$width,$height)]" } {
-	    set ans $maxima_priv(image,$res,$width,$height)
+	if { "" != "[image type $::xmaxima_priv(image,$res,$width,$height)]" } {
+	    set ans $::xmaxima_priv(image,$res,$width,$height)
 	}
     }
     if { "$ans" != "" } { return $ans }
 
     set image [image create photo -width $width -height $height]
     after 10 backgroundGetImage $image [list $resolved] $width $height
-    set maxima_priv(image,$res,$width,$height) $image
+    set ::xmaxima_priv(image,$res,$width,$height) $image
     return $image
 }
 
-
 proc backgroundGetImage  { image res width height }   {
-    global maxima_priv
     #puts [list backgroundGetImage  $image $res $width $height ]
     if { [catch { backgroundGetImage1 $image $res $width $height } err ] } {
         set im ::img::brokenimage
@@ -683,18 +599,16 @@ proc backgroundGetImage  { image res width height }   {
     }
 }
 
-
 proc backgroundGetImage1  { image res width height }   {
     #puts  "resolved=$res"
-    global maxima_priv
     #puts [list backgroundGetImage $image $res $width $height]
     switch [assoc type $res] {
 	http {
 	    set server [assoc server $res]
 	    set port [assoc port $res 80]
-	    if { [info exists maxima_priv(proxy,http) ] } {
-		set s [eval socket $maxima_priv(proxy,http)]
-		#		puts "opening proxy request socket $maxima_priv(proxy,http)"
+	    if { [info exists ::xmaxima_priv(proxy,http) ] } {
+		set s [eval socket $::xmaxima_priv(proxy,http)]
+		#		puts "opening proxy request socket $::xmaxima_priv(proxy,http)"
 	    } else {
 		set s [socket [assoc server $res] [assoc port $res 80]]
 	    }
@@ -705,24 +619,24 @@ proc backgroundGetImage1  { image res width height }   {
 	    flush $s
 
 
-	    if { [regexp -nocase $maxima_priv(imgregexp) [assoc filename $res] mm extension] } {
+	    if { [regexp -nocase $::xmaxima_priv(imgregexp) [assoc filename $res] mm extension] } {
 		fconfigure $s -translation binary
-		set tmp xxtmp[incr maxima_priv(imagecounter)].$extension
+		set tmp xxtmp[incr ::xmaxima_priv(imagecounter)].$extension
 
-		if { [info exists maxima_priv(inbrowser)] ||  [catch {set out [open $tmp w] } ] } {
+		if { [info exists ::xmaxima_priv(inbrowser)] ||  [catch {set out [open $tmp w] } ] } {
 		    # if have binary..
 		    if { "[info command binary]" != "binary" } {
 			error [mc "need version of tk with 'binary' command for images"]}
 		    #puts "hi binary" ; flush stdout
 		    if {  [readAllData $s -tovar \
-			       maxima_priv($s,url_result) -mimeheader \
-			       maxima_priv($s,mimeheader)
-			  ] > 0  && [string match *$extension [assoc content-type $maxima_priv($s,mimeheader)]] } {
+			       ::xmaxima_priv($s,url_result) -mimeheader \
+			       ::xmaxima_priv($s,mimeheader)
+			  ] > 0  && [string match *$extension [assoc content-type $::xmaxima_priv($s,mimeheader)]] } {
 			set ans $image
-			$image configure -data [tobase64 $maxima_priv($s,url_result)]
+			$image configure -data [tobase64 $::xmaxima_priv($s,url_result)]
 
-			unset maxima_priv($s,mimeheader)
-			unset maxima_priv($s,url_result)
+			unset ::xmaxima_priv($s,mimeheader)
+			unset ::xmaxima_priv($s,url_result)
 			
 		    } else  {
 			error [mc "could not get image"]
@@ -732,18 +646,14 @@ proc backgroundGetImage1  { image res width height }   {
 		    if { [readAllData $s -tochannel $out \
 			      -translation binary \
 			      -mimeheader \
-			      maxima_priv($s,mimeheader) -timeout 15000 -chunksize 2024 ] > 0 } {
+			      ::xmaxima_priv($s,mimeheader) -timeout 15000 -chunksize 2024 ] > 0 } {
 			set ans $image
 			$image config  -file \
 			    $tmp
-			unset maxima_priv($s,mimeheader)
+			unset ::xmaxima_priv($s,mimeheader)
 		    }
-
-		
-		
 		    # all the below just to try to remove the file..
 		    #  depending on versions and in environments..
-		
 		}
 	    }
 	}
@@ -768,53 +678,46 @@ proc backgroundGetImage1  { image res width height }   {
     }
 
 }
-
-
 #
 #-----------------------------------------------------------------
 #
-# readData --  read data from S, storing the result
-# in maxima_priv($s,url_result).   It times out after TIMEOUT without any data coming.
-# it can be aborted by setting set maxima_priv($s,done)  -1
+# readData --  read data from S, storing the result in
+# ::xmaxima_priv($s,url_result).   It times out after TIMEOUT without any
+# data coming.
+# It can be aborted by setting set ::xmaxima_priv($s,done)  -1
 #
 #
 #  Results: -1 on failure and 1 on success.
 #
-#  Side Effects: it initially  empties maxima_priv($s,url_result) and then
-#  adds data to it as read.   maxima_priv($s,done) is initialized to 0
+#  Side Effects: it initially  empties ::xmaxima_priv($s,url_result) and then
+#  adds data to it as read.   ::xmaxima_priv($s,done) is initialized to 0
 #
 #----------------------------------------------------------------
 #
 proc readData { s { timeout 10000 }} {
-    global maxima_priv
-
-    after $timeout "set maxima_priv($s,done) -1"
+    after $timeout "set ::xmaxima_priv($s,done) -1"
     fconfigure $s  -blocking 0
-    set maxima_priv($s,done) 0
-    set maxima_priv($s,url_result) ""
+    set ::xmaxima_priv($s,done) 0
+    set ::xmaxima_priv($s,url_result) ""
 
     #mike FIXME: this is a wrong use of after cancel
     fileevent $s readable \
-	"after cancel {set maxima_priv($s,done) -1} ; after $timeout {set maxima_priv($s,done) -1} ; set da \[read $s 8000] ; append maxima_priv($s,url_result) \$da; if { \[string length \$da] < 8000  && \[eof $s] } {after cancel {set maxima_priv($s,done) -1} ; set maxima_priv($s,done) 1; fileevent $s readable {} ;  }"
-    myVwait maxima_priv($s,done)
+	"after cancel {set ::xmaxima_priv($s,done) -1} ; after $timeout {set ::xmaxima_priv($s,done) -1} ; set da \[read $s 8000] ; append ::xmaxima_priv($s,url_result) \$da; if { \[string length \$da] < 8000  && \[eof $s] } {after cancel {set ::xmaxima_priv($s,done) -1} ; set ::xmaxima_priv($s,done) 1; fileevent $s readable {} ;  }"
+    myVwait ::xmaxima_priv($s,done)
     catch { close $s }
     #mike FIXME: this is a wrong use of after cancel
-    after cancel "set maxima_priv($s,done) -1"
-    return $maxima_priv($s,done)
+    after cancel "set ::xmaxima_priv($s,done) -1"
+    return $::xmaxima_priv($s,done)
 }
 
-
-
 proc doRead { sock } {
-    global maxima_priv
-
     #puts reading; flush stdout;
     set tem [read $sock]
-    append maxima_priv(url_result)  $tem
+    append ::xmaxima_priv(url_result)  $tem
     # puts read:<$tem>
     # flush stdout
     if { [eof $sock] } {
-	set maxima_priv(done) 1
+	set ::xmaxima_priv(done) 1
 	close $sock
     }
 }
@@ -842,12 +745,12 @@ proc ws_outputToTemp { string file ext encoding } {
 }
 
 proc OpenMathOpenUrl { name args} {
-    global maxima_priv
+    if {![winfo exists .browser]} {createBrowser .browser}
     
     # Removes any white spaces at the end of the Url given
     set name [string trimright $name]
 
-    gui status [concat [mc "Opening"] "$name"]
+    maxStatus [concat [mc "Opening"] "$name"]
 
     #puts "OpenMathOpenUrl  $name $args "
     set history "" ; set historyIndex -1 ; set currentUrl ""
@@ -897,7 +800,6 @@ proc OpenMathOpenUrl { name args} {
 		    #    pushHistory $commandPanel $v
 		    return
 		}
-		
 	    }
 	} else {
 	    # reload=1
@@ -913,9 +815,8 @@ proc OpenMathOpenUrl { name args} {
 	}
 	set name $tem
     }
-
     #puts "contentType defined:[info exists contentType]"
-    set handler [assoc $contentType $maxima_priv(urlHandlers)]
+    set handler [assoc $contentType $::xmaxima_priv(urlHandlers)]
     if { "$handler" != "netmath" && "$handler" != "" } {
 	set tmp [ws_outputToTemp result netmath ps "[assoc content-encoding $mimeheader]"]
 	# to do fix this for windows #####
@@ -923,7 +824,6 @@ proc OpenMathOpenUrl { name args} {
 	return
     }
     #puts contentType=$contentType
-
     #puts "got [string length $result] bytes"
     #puts ", result= [string range $result 0 70] .."
 
@@ -933,15 +833,12 @@ proc OpenMathOpenUrl { name args} {
     # puts "using  $baseprogram"
     if { $reload } {   forgetCurrent $commandPanel }
 
-    #puts "maxima_priv(counter)=$maxima_priv(counter)"
-
-    set win [mkOpenMath [set w $toplevel.t[incr maxima_priv(counter)]] ]
-
-    #puts "maxima_priv(counter)=$maxima_priv(counter)"
+    #puts "::xmaxima_priv(counter)=$::xmaxima_priv(counter)"
+    set win [mkOpenMath [set w $toplevel.t[incr ::xmaxima_priv(counter)]] ]
 
+    #puts "::xmaxima_priv(counter)=$::xmaxima_priv(counter)"
     makeLocal $w commandPanel
     #puts "resolveURL $name $currentUrl"
-
     if { [set anchor [assoc anchor $new]] != "" } {
 	set new [delassoc anchor $new]
     }
@@ -955,7 +852,6 @@ proc OpenMathOpenUrl { name args} {
     oset $w location  [encodeURL $new]
     # puts "new=$new"
     oset $commandPanel savefilename [file root [toLocalFilename $new]].txt
-
     set tem [assoc filename $new ""]
     #puts $contentType
     if { "$contentType" != "text/html" } {
@@ -988,10 +884,7 @@ proc OpenMathOpenUrl { name args} {
 		$win yview anchor:$anchor
 	    }
 	}
-	
 	#   foreach v {Tresult Teval} {  $win tag raise $v}	
-
-
     } else {
 	###Never get here.. must change to make be the rich text case..	
 	# drop comment lines
@@ -1016,10 +909,8 @@ proc OpenMathOpenUrl { name args} {
 	puts "$errmsg1"
 	error [concat [mc "unable to evaluate"] "[encodeURL $new]\n$errmsg1\n$errorInfo"]
     }
-
 }
 
-
 proc pushHistory { commandPanel win } {
     global [oarray $commandPanel]
     makeLocal $commandPanel history historyIndex
@@ -1031,8 +922,6 @@ proc pushHistory { commandPanel win } {
 	oset $commandPanel history [linsert $history [incr [oloc $commandPanel historyIndex]] $win]
     }
 }
-
-
 #
 #-----------------------------------------------------------------
 #
@@ -1067,8 +956,7 @@ proc addTagSameRange { win oldtag newtag index } {
 }
 
 proc getBaseprogram { } {
-    global maxima_default
-    return [lindex  $maxima_default(defaultservers) 0]
+    return [lindex  $::xmaxima_default(defaultservers) 0]
 }
 
 #mike FIXME: This is an abomination
@@ -1086,12 +974,9 @@ proc fileBaseprogram { textwin parent x y } {
     set com "destroy $e ; oset $textwin baseprogram \[decodeURL \$xHMpriv(baseprogram)] "
     bind $e <Leave> $com
     bind $e <Return> $com
-
 }
 
 proc fontDialog { top } {
-    global maxima_default
-
     set font [xHMmapFont font:propor:normal:r:3]
     if {[winfo exists $top]} {catch { destroy $top }}
 
@@ -1112,10 +997,10 @@ proc fontDialog { top } {
 	if { "$fam" == "fixed" } { set fixed 1 } else {
 	    set fixed 0
 	}
-	mkLabelListBoxChooser $win.size$fam "list $lis" maxima_default($fam,adjust)
-	mkLabelListBoxChooser $win.family$fam "getFontFamilies $fixed " maxima_default($fam)
+	mkLabelListBoxChooser $win.size$fam "list $lis" ::xmaxima_default($fam,adjust)
+	mkLabelListBoxChooser $win.family$fam "getFontFamilies $fixed " ::xmaxima_default($fam)
 	set fo [xHMmapFont "font:$fam:normal:r:3"]
-	catch { set maxima_default($fam) [assoc -family [font actual $fo]]}
+	catch { set ::xmaxima_default($fam) [assoc -family [font actual $fo]]}
     }
     $win insert insert [mc "Font Settings\nThe proportional font is "]
     $win window create insert -window $win.familypropor
@@ -1128,23 +1013,20 @@ proc fontDialog { top } {
     $win insert insert "\n"
     $win insert insert [mc "Default nmtp servers  "]
     global _servers
-    set _servers $maxima_default(defaultservers)
+    set _servers $::xmaxima_default(defaultservers)
     entry $win.entry -textvariable _servers -width 40
     $win window create insert -window $win.entry
     $win insert insert "\n\n"
-    global maxima_priv
     $win insert insert [mc "http Proxy host and port:"]
     entry $win.entryproxy  -width 40
-    catch { $win.entryproxy insert 0 $maxima_priv(proxy,http) }
+    catch { $win.entryproxy insert 0 $::xmaxima_priv(proxy,http) }
     $win window create insert -window $win.entryproxy
-    $win insert insert [mc "\nIf you are behind a firewall enter the name of your http proxy host and port,\n eg: `foo.ma.utexas.edu 3128', otherwise leave this blank"]
+    $win insert insert [mc "\nIf you are behind a firewall enter the name of your http proxy host and port,\n eg: `some.server.example.org 3128', otherwise leave this blank"]
 
-    set men [tk_optionMenu $win.plottype maxima_default(plotwindow) embedded separate multiple ]
+    set men [tk_optionMenu $win.plottype ::xmaxima_default(plotwindow) embedded separate multiple ]
     $win insert insert [mc "\nShould plot windows be "]
     $win window create insert -window $win.plottype
     $win insert insert "?"
-
-
     $win insert insert "\n\n\n"
     $win insert insert [mc " Apply and Quit "] "bye raised"
     $win insert insert "      "
@@ -1152,11 +1034,11 @@ proc fontDialog { top } {
     $win insert insert "      "
     $win insert insert [mc " Cancel "] "cancel raised"
     proc _FontDialogApply { win } {
-	global maxima_default _servers maxima_priv
-	set maxima_default(defaultservers) $_servers
+	global _servers ::xmaxima_priv
+	set ::xmaxima_default(defaultservers) $_servers
 	catch {xHMresetFonts .}
 	if { [llength [$win.entryproxy get]] == 2 } {
-	    set maxima_priv(proxy,http) [$win.entryproxy get]
+	    set ::xmaxima_priv(proxy,http) [$win.entryproxy get]
 	}
     }
     $win tag bind click <1> "_FontDialogApply $win"
@@ -1166,41 +1048,53 @@ proc fontDialog { top } {
     $win insert insert "      "
     $win insert insert [mc " Save Preferences "] "save raised"
     $win tag bind save <1> "_FontDialogApply $win ; savePreferences"
-
     pack $win
     #    place $win -in [oget [omPanel .] textwin] -x 10 -y 10
 }
+
 proc savePreferences {} {
-    global maxima_default maxima_priv
+    makeLocal {.maxima.text} inputs
 
-    # Save current console size in maxima_default
-    set console [lindex [array get maxima_priv cConsoleText] end]
-    set maxima_default(iConsoleWidth) [textWindowWidth $console]
-    set maxima_default(iConsoleHeight) [textWindowHeight $console]
+    # Save current console size in ::xmaxima_default
+    set console [lindex [array get ::xmaxima_priv cConsoleText] end]
+    set ::xmaxima_default(iConsoleWidth) [textWindowWidth $console]
+    set ::xmaxima_default(iConsoleHeight) [textWindowHeight $console]
 
-    if {[catch {open  "~/.xmaximarc" w} fi]} {return}
+    catch {
+        # Save the state of the browser (1=opened, 0=closed)
+        if {[winfo exists .browser]} {
+            set ::xmaxima_default(browser) 1
+        } else {
+            set ::xmaxima_default(browser) 0}
 
-    puts $fi "array set maxima_default {"
-    foreach {k v} [array get maxima_default *] {
-	lappend all [list $k $v]
+        # Save the ::xmaxima_default array into $::xmaxima_priv(conffile)
+        # Each line will contain a key and value separated by space
+        # and the keys will be in alphabetical order
+        #
+        set fileId [open $::xmaxima_priv(conffile) w]
+        foreach {k v} [array get ::xmaxima_default *] {
+            lappend all [list $k $v]
+        }
+        set all [lsort $all]
+        foreach v $all { puts $fileId $v }
+
+        #mike FIXME: make this a _default
+        # if { [info exists ::xmaxima_priv(proxy,http)] && \
+        #          [llength $::xmaxima_priv(proxy,http)] == 2   } {
+        #     puts $fileId [list array set ::xmaxima_priv [array get ::xmaxima_priv proxy,http]
+	# 	 ]
+        # }   Villate: This block seems wrong to me.
+        
+        close $fileId
+
+        # Save the command history to $::xmaxima_priv(history)
+        # Up to 200 last commands are saved, each one as a Tcl list
+        #
+        set fileId [open "$::xmaxima_priv(history)" w]
+        foreach v [lrange $inputs end-199 end] { puts $fileId [list $v] }
+        close $fileId
     }
-    set all [lsort $all]
-    foreach v $all { puts $fi $v }
-    puts $fi "}"
-
-    #mike FIXME: make this a _default
-    if { [info exists maxima_priv(proxy,http)] && [llength $maxima_priv(proxy,http)] == 2   } {
-	puts $fi [list array set maxima_priv [array get maxima_priv proxy,http]
-		 ]
-    }
-    close $fi
 }
-
-
-
-
-
-
 #
 #-----------------------------------------------------------------
 #
@@ -1220,8 +1114,6 @@ proc mkLabelListBoxChooser { win items  textvar} {
 }
 
 proc listBoxChoose { win  items textvar  } {
-    global maxima_default
-
     set whei [winfo height $win]
     set items [eval $items]
     set hei [llength $items]
@@ -1244,11 +1136,8 @@ proc listBoxChoose { win  items textvar  } {
     place $fr -in $win -x 0  -y 0 -anchor n
 }
 
-
 proc quoteForRegexp { s } {
     regsub -all {[\]\[$+()\\.?*]} $s {\\\0}  ans
     return $ans
 }
 
-
-## endsource browser.tcl
