@@ -4,37 +4,80 @@
 # For distribution under GNU public License.  See COPYING. #
 #                                                          #
 #     Modified by Jaime E. Villate                         #
-#     Time-stamp: "2021-04-04 12:05:13 villate"            #
 ############################################################
 
 proc zoomConsole {f} {
-    global maxima_default maxima_priv
-    set ffamily [lindex $maxima_default(ConsoleFont) 0]
-    set fsize [lindex $maxima_default(ConsoleFont) 1]
+    set ffamily [lindex $::xmaxima_default(ConsoleFont) 0]
+    set fsize [lindex $::xmaxima_default(ConsoleFont) 1]
     set fsize [expr round($fsize*pow(1.2,$f))]
     font configure ConsoleFont -family $ffamily -size $fsize
-    set text $maxima_priv(cConsoleText)
+    set text $::xmaxima_priv(cConsoleText)
     resizeSubPlotWindows $text [winfo width $text] [winfo height $text]
     resizeMaxima $text [winfo width $text] [winfo height $text]
-    set maxima_default(ConsoleFont) [list $ffamily $fsize]
+    set ::xmaxima_default(ConsoleFont) [list $ffamily $fsize]
+}
+
+proc fileType {type} {
+    switch -exact -- $type output {
+        return [list {"Output Files" .out} {"All Files" *}]
+    } lisp {
+        return [list {"Lisp Files" {.lisp}} {"All Files" *}]
+    } maxima {
+        return [list {"Maxima Files" {.mac .mc .dem}} {"All Files" *}]
+    } all - default {
+        return [list {"All Files" *}]}}
+
+proc getOpenFile {title {type "all"}} {
+    set types [fileType $type]
+    set file $::xmaxima_default(OpenFile)
+    if {$file ne ""} {set dir [file dir $file]} {set dir ""}
+    set proc tk_getOpenFile
+    set list [list $proc -title $title -filetypes $types]
+    if {$dir ne ""} {lappend list  -initialdir [file native $dir]}
+    if {[catch {eval $list} retval]} {
+	global errorInfo
+	tk_messageBox -title Error -icon error -message \
+            [mc "Error opening file:\n%s" $errorInfo]
+	return ""}
+    if {$retval ne ""} { set ::xmaxima_default(OpenFile) $retval }
+    return $retval}
+
+proc getSaveFile {title {type "all"}} {
+    set types [fileType $type]
+    set file $::xmaxima_default(SaveFile)
+    if {$file ne ""} {set dir [file dir $file]} {set dir ""}
+    set proc tk_getSaveFile
+    set list [list $proc -title $title -filetypes $types]
+    if {$dir ne ""} {lappend list -initialdir [file native $dir]}
+    if {[catch {eval $list} retval]} {
+	global errorInfo
+	tk_messageBox -title Error -icon error -message \
+            [mc "Error saving file:\n%s" $errorInfo]
+	return ""}
+    if {$retval ne ""} { set ::xmaxima_default(SaveFile) $retval }
+    return $retval}
+
+proc cIDECreateEvent {text label code} {
+    set z [winfo toplevel $text]
+    set event "<<[join $label -]>>"
+    bind $text $event $code
+    return [list event generate $text $event]
 }
 
 proc pMAXSaveTexToFile {text} {
-    set file [tide_savefile [M [mc "Save to a file"]] "" *.out]
+    set file [getSaveFile [mc "Save to a file"] output]
     if {$file != ""} {
 	set contents [$text get 1.0 end]
 	set fd [open $file w]
 	if {[catch {puts $fd $contents} err]} {
-	    tide_failure [M [mc "Error writing to file:\n%s"] $err]
+	    tk_messageBox -title Error -icon error -message \
+                [mc "Error writing to file:\n%s" $err]
 	}
 	catch {close $fd}
     }
 }
 
 proc vMAXAddBrowserMenu {win} {
-    global maxima_priv maxima_default
-    global tcl_platform env
-
     if {[winfo exists .browser.menu]} {destroy .browser.menu}
     set bm .browser.menu
     menu $bm
@@ -64,49 +107,45 @@ proc vMAXAddBrowserMenu {win} {
 }
 
 proc vMAXAddSystemMenu {fr text} {
-    global maxima_priv maxima_default
-    global tcl_platform env
     set win $fr.textcommands
-
     # Build a menubar
     if {[winfo exists .menu]} {destroy .menu}
     menu .menu
     . configure -menu .menu
-
     # Add a File menu
     set m [menu .menu.file -tearoff 0]
     .menu add cascade -label [mc "File"] -menu $m -underline 0
     $m add command -underline 0 \
 	-accel {Alt+b} \
-	-label [set label [M [mc "Batch File"]]] \
+	-label [set label [mc "Batch File"]] \
 	-command [set command [cIDECreateEvent $text $label {
-	    set file [tide_openfile [M [mc "Open a file to Batch"]] "" *.mac]
+	    set file [getOpenFile [mc "Open a file to Batch"] maxima]
 	    if {$file != ""} {
-		sendMaxima $maxima_priv(cConsoleText) "batch(\"$file\")\$\n"
-		gui status [concat [mc "Batched File "] "$file"]
+		sendMaxima $::xmaxima_priv(cConsoleText) "batch(\"$file\")\$\n"
+		maxStatus [concat [mc "Batched File "] "$file"]
 	    }
 	}]]
     bind $text <Alt-Key-b> $command
     $m add command -underline 11 \
 	-accel {Alt+o} \
-	-label [set label [M [mc "Batch File Silently"]]] \
+	-label [set label [mc "Batch File Silently"]] \
 	-command [set command [cIDECreateEvent $text $label {
-	    set file [tide_openfile [M [mc "Open a file to Batch Silently"]] "" *.mac]
+	    set file [getOpenFile [mc "Open a file to Batch Silently"] maxima]
 	    if {$file != ""} {
-		sendMaxima $maxima_priv(cConsoleText) "batchload(\"$file\")\$\n"
-		gui status [concat [mc "Batched File "] "$file"]
+		sendMaxima $::xmaxima_priv(cConsoleText) "batchload(\"$file\")\$\n"
+		maxStatus [concat [mc "Batched File "] "$file"]
 	    }
 	}]]
     bind $text <Alt-Key-o> $command
 
     $m add command -underline 11 \
 	-accel {Alt+i} \
-	-label [set label [M [mc "Restore Maxima State"]]] \
+	-label [set label [mc "Restore Maxima State"]] \
 	-command [set command [cIDECreateEvent $text $label {
-	    set file [tide_openfile [M [mc "Open a file to Restore State"]] "" *.lisp]
+	    set file [getOpenFile [mc "Open a file to Restore State"] lisp]
 	    if {$file != ""} {
-		sendMaxima $maxima_priv(cConsoleText) ":lisp-quiet (prog2 (mfuncall '\$load \"$file\") nil)\n"
-		gui status [concat [mc "Maxima State Restored from "] "$file"]
+		sendMaxima $::xmaxima_priv(cConsoleText) ":lisp-quiet (prog2 (mfuncall '\$load \"$file\") nil)\n"
+		maxStatus [concat [mc "Maxima State Restored from "] "$file"]
 	    }
 	}]]
     bind $text <Alt-Key-i> $command
@@ -116,10 +155,10 @@ proc vMAXAddSystemMenu {fr text} {
 	-label [set label [mc "Save Maxima State to File"]] \
 	-accel {Ctrl+s} \
 	-command [set command [cIDECreateEvent $text $label {
-	    set file [tide_savefile [M [mc "Save to a file"]] "" *.lisp]
+	    set file [getSaveFile [mc "Save to a file"] lisp]
 	    if {$file != ""} {
-		sendMaxima $maxima_priv(cConsoleText) ":lisp-quiet (prog2 (mfuncall '\$save \"$file\" '\$all) nil)\n"
-		gui status [concat [mc "Maxima State Saved to "] "$file"]
+		sendMaxima $::xmaxima_priv(cConsoleText) ":lisp-quiet (prog2 (mfuncall '\$save \"$file\" '\$all) nil)\n"
+		maxStatus [concat [mc "Maxima State Saved to "] "$file"]
 	    }
 	}]]
     bind $text <Control-Key-s> $command
@@ -128,10 +167,10 @@ proc vMAXAddSystemMenu {fr text} {
 	-label [set label [mc "Save Maxima Input to File"]] \
 	-accel {Ctrl+a} \
 	-command [set command [cIDECreateEvent $text $label {
-	    set file [tide_savefile [M [mc "Save to a file"]] "" *.mac]
+	    set file [getSaveFile [mc "Save to a file"] maxima]
 	    if {$file != ""} {
-		sendMaxima $maxima_priv(cConsoleText) ":lisp-quiet (prog2 (mfuncall '\$stringout \"$file\" '\$input) nil)\n"
-		gui status [concat [mc "Maxima Input Saved to "] "$file"]
+		sendMaxima $::xmaxima_priv(cConsoleText) ":lisp-quiet (prog2 (mfuncall '\$stringout \"$file\" '\$input) nil)\n"
+		maxStatus [concat [mc "Maxima Input Saved to "] "$file"]
 	    }
 	}]]
     bind $text <Control-Key-a> $command
@@ -149,9 +188,8 @@ proc vMAXAddSystemMenu {fr text} {
 	-command [list event generate $text <Alt-Key-s>]
 
     $m add separator
-    $m add command -underline 1 \
-	-label [mc "Exit"] \
-	-command [list tkmaxima exit $text]
+    $m add command -underline 1 -label [mc "Exit"] \
+        -command [list maxExit $text]
 
     # Add an Edit menubutton
     set m [menu .menu.edit -tearoff 0]
@@ -193,17 +231,19 @@ proc vMAXAddSystemMenu {fr text} {
 	-command [list CNclearinput $text]
     $m add separator
     $m add command -underline 0 -label [mc "Save Console to File"] \
-	-command [list pMAXSaveTexToFile $maxima_priv(cConsoleText)]
+	-command [list pMAXSaveTexToFile $::xmaxima_priv(cConsoleText)]
 
-    # Add a Options menubutton
+    # Add an Options menubutton
     set m [menu .menu.options -tearoff 0]
     .menu add cascade -label [mc "Options"] -menu $m -underline 0
     $m add separator
+    $m add command -label [mc "Open the Browser"] \
+        -command [list createBrowser .browser]
     set pm [menu $m.plot]
     $m add cascade -label [mc "Plot Windows"] -menu $pm
     foreach elt { embedded separate multiple } {
 	$pm add radio -label [mc [string totit $elt]] \
-	    -variable maxima_default(plotwindow) \
+	    -variable ::xmaxima_default(plotwindow) \
 	    -value $elt -command [list SetPlotFormat $text ]
     }
     # $m add separator
@@ -231,7 +271,7 @@ proc vMAXAddSystemMenu {fr text} {
 	    -command [list sendMaxima $text "kill($elt)\$\n"]
     }
     $m add separator  
-    set dir $maxima_priv(pTestsDir)  
+    set dir $::xmaxima_priv(pTestsDir)  
     if {[file isdir $dir]} {
 	set state normal
     } else {
@@ -251,33 +291,35 @@ proc vMAXAddSystemMenu {fr text} {
     .menu add cascade -label [mc "Help"] -menu $m -underline 0
 
     # Xmaxima manual
-    set xmaximahelpfile [file join $maxima_priv(maxima_verpkgdatadir) xmaxima html xmaxima.html]
+    set xmaximahelpfile [file join $::xmaxima_priv(maxima_verpkgdatadir) xmaxima html index.html]
     set xmaximahelpfile [file normalize $xmaximahelpfile]
-    if {[file isfile $xmaximahelpfile]} {
-	set xstate normal
-    } else {
-	set xstate disabled
-    }
+    set xstate normal
+    # if {[file isfile $xmaximahelpfile]} {
+    #     set xstate normal
+    # } else {
+    #     set xstate disabled
+    # }
     # Maxima manual
-    set file $maxima_priv(pReferenceToc)
-    if {[file isfile $file]} {
-	set state normal
-	if {$tcl_platform(platform) == "windows"} {
-	    # decodeURL is broken and needs fixing
-	    # This is a workaround
-	    set file [file attrib $file -shortname]
-	}
-    } else {
-	set state disabled
+    set file $::xmaxima_priv(pReferenceToc)
+    if {$::tcl_platform(platform) == "windows"} {
+        # decodeURL is broken and needs fixing
+        # This is a workaround
+        set file [file attrib $file -shortname]
     }
-    if {$tcl_platform(platform) == "windows"} {
+    set state normal
+    # if {[file isfile $file]} {
+    #     set state normal
+    # } else {
+    #     set state disabled
+    # }
+    if {$::tcl_platform(platform) == "windows"} {
         if {[string match *maxima.chm* $file]} {
             $m add command -underline 1 -label [mc "Maxima Manual"] \
          	    -state $state \
 	            -command [list exec hh.exe $file & ]
         } else {
             $m add command -underline 1 -label [mc "Maxima Manual (xmaxima browser)"] \
-        	    -state $state \
+        	    -state normal \
 	            -command "OpenMathOpenUrl \"file:/$file\""
         }
         $m add command -underline 4 -label [mc "Xmaxima Manual (xmaxima browser)"] \
@@ -294,8 +336,8 @@ proc vMAXAddSystemMenu {fr text} {
     set browse {exec}
 
     # FIXME: get a browser object
-    if {$tcl_platform(platform) == "windows"} {
-	if {$tcl_platform(os) == "Windows 95"} {
+    if {$::tcl_platform(platform) == "windows"} {
+	if {$::tcl_platform(os) == "Windows 95"} {
 	    # Windows 95/98/ME
 	    lappend browse start
 	} else {
@@ -313,7 +355,7 @@ proc vMAXAddSystemMenu {fr text} {
 	lappend browse $selectedbrowser
     }
     $m add separator
-    if {$tcl_platform(platform) != "windows"} {
+    if {$::tcl_platform(platform) != "windows"} {
 	$m add command -underline 0 -label [mc "Maxima Manual (web browser)"] \
 	    -command [list eval $browse "file://$file" &]
     }
@@ -343,8 +385,7 @@ proc vMAXAddSystemBar {} {
 }
 
 proc SetPlotFormat { text } {
-    global maxima_default
-    if { $maxima_default(plotwindow) == "embedded" } {
+    if { $::xmaxima_default(plotwindow) == "embedded" } {
 	sendMaxima $text ":lisp-quiet (prog2 (\$set_plot_option '((mlist simp) \$plot_format \$xmaxima)) nil) \n"
     }
 }
