@@ -1,13 +1,13 @@
 ;;; Compiled by f2cl version:
-;;; ("f2cl1.l,v 1.215 2009/04/07 22:05:21 rtoy Exp $"
-;;;  "f2cl2.l,v 1.37 2008/02/22 22:19:33 rtoy Exp $"
-;;;  "f2cl3.l,v 1.6 2008/02/22 22:19:33 rtoy Exp $"
-;;;  "f2cl4.l,v 1.7 2008/02/22 22:19:34 rtoy Exp $"
-;;;  "f2cl5.l,v 1.200 2009/01/19 02:38:17 rtoy Exp $"
-;;;  "f2cl6.l,v 1.48 2008/08/24 00:56:27 rtoy Exp $"
-;;;  "macros.l,v 1.112 2009/01/08 12:57:19 rtoy Exp $")
+;;; ("f2cl1.l,v 2edcbd958861 2012/05/30 03:34:52 toy $"
+;;;  "f2cl2.l,v 96616d88fb7e 2008/02/22 22:19:34 rtoy $"
+;;;  "f2cl3.l,v 96616d88fb7e 2008/02/22 22:19:34 rtoy $"
+;;;  "f2cl4.l,v 96616d88fb7e 2008/02/22 22:19:34 rtoy $"
+;;;  "f2cl5.l,v 3fe93de3be82 2012/05/06 02:17:14 toy $"
+;;;  "f2cl6.l,v 1d5cbacbb977 2008/08/24 00:56:27 rtoy $"
+;;;  "macros.l,v 3fe93de3be82 2012/05/06 02:17:14 toy $")
 
-;;; Using Lisp CMU Common Lisp 19f (19F)
+;;; Using Lisp CMU Common Lisp 20d (20D Unicode)
 ;;; 
 ;;; Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t)
 ;;;           (:coerce-assigns :as-needed) (:array-type ':array)
@@ -66,20 +66,26 @@
                        one)
                (dlarf "Left" (f2cl-lib:int-add (f2cl-lib:int-sub m i) 1)
                 (f2cl-lib:int-sub n i)
-                (f2cl-lib:array-slice a double-float (i i) ((1 lda) (1 *))) 1
-                (f2cl-lib:fref tau-%data% (i) ((1 *)) tau-%offset%)
-                (f2cl-lib:array-slice a
+                (f2cl-lib:array-slice a-%data%
+                                      double-float
+                                      (i i)
+                                      ((1 lda) (1 *))
+                                      a-%offset%)
+                1 (f2cl-lib:fref tau-%data% (i) ((1 *)) tau-%offset%)
+                (f2cl-lib:array-slice a-%data%
                                       double-float
                                       (i (f2cl-lib:int-add i 1))
-                                      ((1 lda) (1 *)))
+                                      ((1 lda) (1 *))
+                                      a-%offset%)
                 lda work)))
             (if (< i m)
                 (dscal (f2cl-lib:int-sub m i)
                  (- (f2cl-lib:fref tau-%data% (i) ((1 *)) tau-%offset%))
-                 (f2cl-lib:array-slice a
+                 (f2cl-lib:array-slice a-%data%
                                        double-float
                                        ((+ i 1) i)
-                                       ((1 lda) (1 *)))
+                                       ((1 lda) (1 *))
+                                       a-%offset%)
                  1))
             (setf (f2cl-lib:fref a-%data% (i i) ((1 lda) (1 *)) a-%offset%)
                     (- one
@@ -95,7 +101,7 @@
        end_label
         (return (values nil nil nil nil nil nil nil info))))))
 
-(in-package #-gcl #:cl-user #+gcl "CL-USER")
+(in-package #:cl-user)
 #+#.(cl:if (cl:find-package '#:f2cl) '(and) '(or))
 (eval-when (:load-toplevel :compile-toplevel :execute)
   (setf (gethash 'fortran-to-lisp::dorg2r
