@@ -1,6 +1,6 @@
 ;;; -*-  Mode: Lisp; Package: Maxima; Syntax: Common-Lisp; Base: 10 -*- ;;;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;;;     The data in this file contains enhancments.                    ;;;;;
+;;;     The data in this file contains enhancements.                   ;;;;;
 ;;;                                                                    ;;;;;
 ;;;  Copyright (c) 1984,1987 by William Schelter,University of Texas   ;;;;;
 ;;;     All rights reserved                                            ;;;;;
@@ -12,16 +12,7 @@
 
 (macsyma-module comm)
 
-(declare-top (special $exptsubst $linechar $nolabels $inflag $piece $dispflag
-		      $gradefs $props $dependencies derivflag derivlist
-		      $linenum $partswitch *linelabel* nn* dn*
-		      $powerdisp atvars $errexp $derivsubst $dotdistrib
-		      $opsubst $subnumsimp $transrun in-p substp $sqrtdispflag
-		      $pfeformat dummy-variable-operators))
-
-(defvar *islinp* nil) ; When T, sdiff is called from the function islinear.
-(defvar *atp* nil)    ; When T, prevents substitution from applying to vars 
-                      ; bound by %sum, %product, %integrate, %limit
+(declare-top (special *linelabel*))
 
 ;; op and opr properties
 
@@ -45,11 +36,16 @@
     (and (symbolp x) (remprop x 'opr))
     (and (stringp x) (remhash x *opr-table*))))
 
-;; Store built-in operators, which get additional properties.
-;; These operators aren't killed by the function kill-operator.
-(defvar *mopl* nil)
+;; This business about operator properties is terrible --
+;; this stuff should be in src/nparse.lisp, and it should be split up
+;; for each operator. Extra points for making it declarative.
+
+(mapc #'(lambda (x)
+          (putprop (car x) (cadr x) 'op)
+          (putprop (intern (concatenate 'string "%" (symbol-name (car x)))) (cadr x) 'op) ;; nounify not yet available
+          (putopr (cadr x) (car x))
+          (push (cadr x) *mopl*))
 
-(mapc #'(lambda (x) (putprop (car x) (cadr x) 'op) (putopr (cadr x) (car x)) (push (cadr x) *mopl*))
       '((mplus "+") (mminus "-") (mtimes "*") (mexpt "**") (mexpt "^")
 	(mnctimes ".") (rat "/") (mquotient "/") (mncexpt "^^")
 	(mequal "=") (mgreaterp ">") (mlessp "<") (mleqp "<=") (mgeqp ">=")
@@ -61,25 +57,30 @@
 (mapc #'(lambda (x) (putprop (car x) (cadr x) 'op))
       '((mqapply $subvar) (bigfloat $bfloat)))
 
-(defmvar $exptsubst nil)
-(defmvar $partswitch nil)
-(defmvar $inflag nil)
-(defmvar $derivsubst nil)
-(defmvar $opsubst t)
-(defvar $gradefs '((mlist simp)))
-(defvar $dependencies '((mlist simp)))
-(defvar atvars '($@1 $@2 $@3 $@4))
-(defvar in-p nil)
-(defvar substp nil)
-
 (defmvar $vect_cross nil
   "If TRUE allows DIFF(X~Y,T) to work where ~ is defined in
 	  SHARE;VECT where VECT_CROSS is set to TRUE.")
 
-(defmfun $substitute (old new &optional (expr nil three-arg?))
-  (cond (three-arg? (maxima-substitute old new expr))
+(defmfun $listp (x)
+  (and (not (atom x))
+       (not (atom (car x)))
+       (eq (caar x) 'mlist)))
+
+(defun atomchk (e fun 2ndp)
+  (if (or (atom e) (eq (caar e) 'bigfloat))
+      (merror (intl:gettext "~:M: ~Margument must be a non-atomic expression; found ~M") fun (if 2ndp "2nd " "") e)))
+
+(defmfun $member (x e)
+  (atomchk e '$member t)
+  (setq x (specrepcheck x))
+  (dolist (i (margs e))
+    (when (alike1 x (specrepcheck i))
+      (return t))))
+
+(defmfun $substitute (new old &optional (expr nil three-arg?))
+  (cond (three-arg? (maxima-substitute new old expr))
 	(t
-	 (let ((l old) (z new))
+	 (let ((l new) (z old))
 	   (cond ((and ($listp l) ($listp (cadr l)) (null (cddr l)))
 		  ($substitute (cadr l) z))
 		 ((notloreq l) (improper-arg-err l '$substitute))
@@ -136,33 +137,39 @@
                         (setq z (maxima-substitute (cdar l) (caar l) z))))))))))
 
 (defun maxima-substitute (x y z) ; The args to SUBSTITUTE are assumed to be simplified.
-  (let ((in-p t) (substp t))
-    (if (and (mnump y) (= (signum1 y) 1))
-	(let ($sqrtdispflag ($pfeformat t)) (setq z (nformat-all z))))
-    (simplifya
-     (if (atom y)
-	 (cond ((equal y -1)
-		(setq y '((mminus) 1)) (subst2 x y (nformat-all z) nil nil)) ;; negxpty and timesp don't matter in this call since (caar y) != 'mexpt
-	       (t
-		(cond ((and (not (symbolp x))
-			    (functionp x))
-		       (let ((tem (gensym)))
-			 (setf (get  tem  'operators) 'application-operator)
-			 (setf (symbol-function tem) x)
-			 (setq x tem))))
-		(subst1 x y z)))
-	 (let ((negxpty (if (and (eq (caar y) 'mexpt)
-				 (= (signum1 (caddr y)) 1))
-			    (mul2 -1 (caddr y))))
-	       (timesp (if (eq (caar y) 'mtimes) (setq y (nformat y)))))
-	   (subst2 x y z negxpty timesp)))
-     nil)))
+  ;; Prevent replacing dependent variable with constant in derivative
+  (cond ((and (not (atom z))
+              (eq (caar z) '%derivative)
+              (eq (cadr z) y)
+              (typep x 'number))
+         z)
+        (t
+         (let ((in-p t) (substp t))
+           (if (and (mnump y) (= (signum1 y) 1))
+	       (let ($sqrtdispflag ($pfeformat t)) (setq z (nformat-all z))))
+           (simplifya
+            (if (atom y)
+	        (cond ((equal y -1)
+		       (setq y '((mminus) 1))
+                       (subst2 x y (nformat-all z) nil nil)) ;; negxpty and timesp don't matter in this call since (caar y) != 'mexpt
+	              (t
+		       (cond ((and (not (symbolp x))
+			           (functionp x))
+		              (let ((tem (gensym)))
+			        (setf (get  tem  'operators) 'application-operator)
+			        (setf (symbol-function tem) x)
+			        (setq x tem))))
+		       (subst1 x y z)))
+	        (let ((negxpty (if (and (eq (caar y) 'mexpt)
+				        (= (signum1 (caddr y)) 1))
+			           (mul2 -1 (caddr y))))
+	              (timesp (if (eq (caar y) 'mtimes)
+                                  (setq y (nformat y)))))
+	          (subst2 x y z negxpty timesp)))
+            nil)))))
 
 ;;Remainder of page is update from F302 --gsb
 
-;;Used in COMM2 (AT), limit, and below.
-(defvar dummy-variable-operators '(%product %sum %laplace %integrate %limit %at))
-
 (defun subst1 (x y z)			; Y is an atom
   (cond ((atom z) (if (equal y z) x z))
 	((specrepp z) (subst1 x y (specdisrep z)))
@@ -394,7 +401,6 @@
 	     (add2lnc (cons (cons (caar z) nil) (cdr z)) $gradefs) z))))
 
 (defmfun $diff (&rest args)
-  #-gcl
   (declare (dynamic-extent args))
   (let (derivlist)
     (deriv args)))
@@ -506,7 +512,7 @@
 	 (cond ((or (atom (cadr e)) (member 'array (cdaadr e) :test #'eq)) (chainrule e x))
 	       ((freel (cddr e) x) (diff%deriv (cons (sdiff (cadr e) x) (cddr e))))
 	       (t (diff%deriv (list e x 1)))))
-	((member (caar e) '(%binomial $beta) :test #'eq)
+	((member (caar e) '(%binomial %beta) :test #'eq)
 	 (let ((efact ($makefact e)))
 	   (mul2 (factor (sdiff efact x)) (div e efact))))
 	((eq (caar e) '%integrate) (diffint e x))
@@ -550,10 +556,10 @@
                result))
 
 	  ;; extension for pdiff.
-	  ((and (get '$pderivop 'operators) (funcall 'sdiffgrad-pdiff e x)))
+	  ((and (get '$pderivop 'operators) (mfuncall 'sdiffgrad-pdiff e x)))
 
 	  ;; two line extension for hypergeometric.
-	  ((and (equal fun '$hypergeometric) (get '$hypergeometric 'operators))
+	  ((and (equal fun '%hypergeometric) (get '%hypergeometric 'operators))
 	   (funcall 'diff-hypergeometric (second e) (third e) (fourth e) x))
 
 	  ((or (eq fun 'mqapply) (null (setq grad (zl-get fun 'grad))))
@@ -665,7 +671,7 @@
 		 ((mexpt) $%e ((mtimes) -1 ((mexpt) x 2)))))
 	  )))
 
-(defprop $atan2 ((x y) ((mtimes) y ((mexpt) ((mplus) ((mexpt) x 2) ((mexpt) y 2)) -1))
+(defprop %atan2 ((x y) ((mtimes) y ((mexpt) ((mplus) ((mexpt) x 2) ((mexpt) y 2)) -1))
 		 ((mtimes) -1 x ((mexpt) ((mplus) ((mexpt) x 2) ((mexpt) y 2)) -1)))
   grad)
 
@@ -723,8 +729,7 @@
 (defun nthelem (n e)
   (car (nthcdr (1- n) e)))
 
-(defun delsimp (e)
-  (delete 'simp (copy-list e) :count 1 :test #'eq))
+(defun delsimp (e) (remove 'simp e))
 
 (defun remsimp (e)
   (if (atom e) e (cons (delsimp (car e)) (mapcar #'remsimp (cdr e)))))
@@ -747,7 +752,6 @@
   (disp1 (cdr form) t t))
 
 (defmfun $ldisp (&rest args)
-  #-gcl
   (declare (dynamic-extent args))
   (disp1 args t nil))
 
@@ -755,7 +759,6 @@
   (disp1 (cdr form) nil t))
 
 (defmfun $disp (&rest args)
-  #-gcl
   (declare (dynamic-extent args))
   (disp1 args nil nil))
 
@@ -773,7 +776,6 @@
     (if lablist (nconc lablist (cons (elabel ans) nil)))
     (setq tim (get-internal-run-time))
     (let ((*display-labels-p* (not (null lablist))))
-      (declare (special *display-labels-p*))
       (displa (list '(mlabel) (if lablist *linelabel*) ans)))
     (mterpri)
     (timeorg tim)))
@@ -830,20 +832,19 @@
 ;;; These functions implement the Macsyma functions $op and $operatorp.
 ;;; Dan Stanger
 (defmfun $op (expr)
-  ($part expr 0))
+  (let (($partswitch nil))
+    ($part expr 0)))
 
 (defmfun $operatorp (expr oplist)
   (if ($listp oplist)
       ($member ($op expr) oplist)
-      (equal ($op expr) oplist)))
+      (alike1 ($op expr) oplist)))
 
 (defmfun $part (&rest args)
-  #-gcl
   (declare (dynamic-extent args))
   (mpart args nil nil $inflag '$part))
 
 (defmfun $inpart (&rest args)
-  #-gcl
   (declare (dynamic-extent args))
   (mpart args nil nil t '$inpart))
 
@@ -855,21 +856,26 @@
   (let ((substp t))
     (mpart (cdr l) t nil t '$substinpart)))
 
-(defun part1 (arglist substflag dispflag inflag) ; called only by TRANSLATE
+(defun part1 (arglist substflag dispflag inflag fn) ; called only by TRANSLATE
   (let ((substp t))
-    (mpart arglist substflag dispflag inflag '$substpart)))
+    (mpart arglist substflag dispflag inflag fn)))
+
+(defun make-mbox-for-mpart (e label)
+  (if (eq label t)
+      (list '(mbox) e)
+      (make-mbox e (car label))))
 
 (defun mpart (arglist substflag dispflag inflag fn)
   (prog (substitem arg arg1 exp exp1 exp* sevlist count prevcount n specp
 	 lastelem lastcount)
      (setq specp (or substflag dispflag))
      (if substflag (setq substitem (car arglist) arglist (cdr arglist)))
-     (if (null arglist) (wna-err '$part))
+     (if (null arglist) (wna-err fn))
      (setq exp (if substflag (meval (car arglist)) (car arglist)))
      (when (null (setq arglist (cdr arglist)))
        (setq $piece exp)
        (return (cond (substflag (meval substitem))
-		     (dispflag (box exp dispflag))
+		     (dispflag (make-mbox-for-mpart exp dispflag))
 		     (t exp))))
      (cond ((not inflag)
 	    (cond ((or (and ($listp exp) (null (cdr arglist)))
@@ -919,7 +925,7 @@
 							  '(array))))
 				    (resimplify exp*))
 				   (dispflag
-				    (rplacd exp (cdr (box (copy-tree exp) dispflag)))
+				    (rplacd exp (cdr (make-mbox-for-mpart (copy-tree exp) dispflag)))
 				    (rplaca exp (if (eq dispflag t)
 						    '(mbox)
 						    '(mlabox)))
@@ -939,7 +945,7 @@
 					  (rplaca exp (meval substitem))
 					  (resimplify exp*))
 			       (dispflag (setq $piece (resimplify (car exp)))
-					 (rplaca exp (box (car exp) dispflag))
+					 (rplaca exp (make-mbox-for-mpart (car exp) dispflag))
 					 (resimplify exp*))
 			       (inflag (setq $piece (car exp)))
 			       (t (setq $piece (simplify (car exp))))))))
@@ -996,12 +1002,12 @@
 		 (return (cond (substflag (rplaca (nthcdr (1- lastcount) exp1)
 						  (meval substitem))
 					  (resimplify exp*))
-			       (dispflag (rplaca exp (box (car exp) dispflag))
+			       (dispflag (rplaca exp (make-mbox-for-mpart (car exp) dispflag))
 					 (resimplify exp*))
 			       (t $piece))))
 		(substflag (if (null (cdr exp)) (go err))
 			   (rplaca exp (cadr exp)) (rplacd exp (cddr exp)))
-		(dispflag (rplaca exp (box (car exp) dispflag))
+		(dispflag (rplaca exp (make-mbox-for-mpart (car exp) dispflag))
 			  (setq exp (cdr exp)))
 		(t (setq exp exp1)))
      (go sevloop)))
@@ -1009,31 +1015,26 @@
 (defun getop (x)
   (or (and (symbolp x) (get x 'op)) x))
 
-(defmfun $listp (x)
-  (and (not (atom x))
-       (not (atom (car x)))
-       (eq (caar x) 'mlist)))
-
 (defmfun $cons (x e)
   (atomchk (setq e (format1 e)) '$cons t)
-  (mcons-exp-args e (cons x (margs e))))
+  (simplifya (mcons-exp-args e (cons x (margs e))) t))
 
 (defmfun $endcons (x e)
   (atomchk (setq e (format1 e)) '$endcons t)
-  (mcons-exp-args e (append (margs e) (ncons x))))
+  (simplifya (mcons-exp-args e (append (margs e) (ncons x))) t))
 
 (defmfun $reverse (e)
   (atomchk (setq e (format1 e)) '$reverse nil)
-  (mcons-exp-args e (reverse (margs e))))
+  (simplifya (mcons-exp-args e (reverse (margs e))) t))
 
 (defmfun $append (&rest args)
   (if (null args)
-      '((mlist simp))
+      (simplifya '((mlist)) t)
       (let ((arg1 (specrepcheck (first args))) op arrp)
 	(atomchk arg1 '$append nil)
 	(setq op (mop arg1)
 	      arrp (if (member 'array (cdar arg1) :test #'eq) t))
-	(mcons-exp-args
+	(simplifya (mcons-exp-args
 	 arg1
 	 (apply #'append
 		(mapcar #'(lambda (u)
@@ -1042,21 +1043,14 @@
 					 (eq arrp (if (member 'array (cdar u) :test #'eq) t)))
 			      (merror (intl:gettext "append: operators of arguments must all be the same.")))
 			    (margs u))
-			args))))))
+			args)))
+      t))))
 
 (defun mcons-exp-args (e args)
   (if (eq (caar e) 'mqapply)
       (list* (delsimp (car e)) (cadr e) args)
       (cons (delsimp (car e)) args)))
 
-(defmfun $member (x e)
-  (atomchk (setq e ($totaldisrep e)) '$member t)
-  (if (memalike ($totaldisrep x) (margs e)) t))
-
-(defun atomchk (e fun 2ndp)
-  (if (or (atom e) (eq (caar e) 'bigfloat))
-      (merror (intl:gettext "~:M: ~Margument must be a non-atomic expression; found ~M") fun (if 2ndp "2nd " "") e)))
-
 (defun format1 (e)
   (cond (($listp e) e)
 	($inflag (specrepcheck e))
@@ -1139,8 +1133,9 @@
       ($rest e (- m n)))))
 
 (defmfun $args (e)
-  (atomchk (setq e (format1 e)) '$args nil)
-	 (cons '(mlist) (margs e)))
+ (let ((formatted (format1 e)))
+  (atomchk formatted '$args nil)
+	 (simplifya (cons '(mlist) (margs formatted)) (eq e formatted))))
 
 (defmfun $delete (x l &optional (n -1 n?))
   (when (and n? (or (not (fixnump n)) (minusp n))) ; if n is set, it must be a nonneg fixnum
@@ -1206,9 +1201,9 @@
 ;; number.  Otherwise, return NIL to indicate that we the computation
 ;; failed.  This is a pretty brute-force approach.
 (defun try-float-computation (thunk)
-  (let ((errcatch (cons bindlist loclist))
+  (let ((errset nil)
+	(errcatch (cons bindlist loclist))
 	(*mdebug* nil))
-    (declare (special errcatch))
     (let ((result (errset (funcall thunk))))
       (labels ((bad-number-p (num)
 		 (if (complexp num)
@@ -1222,7 +1217,10 @@
 	    
 (defmfun $float (e)
   (cond ((numberp e)
-	 (let ((e1 (float e))) (if (float-inf-p e1) (signal 'floating-point-overflow) e1)))
+	 (let ((e1 (float e))) (if (float-inf-p e1) (error 'floating-point-overflow) e1)))
+	((eq e '$%i)
+	 ;; Handle %i specially.
+	 (mul 1.0 '$%i))
 	((and (symbolp e) (mget e '$numer)))
 	((or (atom e) (member 'array (cdar e) :test #'eq)) e)
 	((eq (caar e) 'rat) (fpcofrat e))
@@ -1265,8 +1263,7 @@
 			      ($float `((%log) ,(third n)))))))
 		 ((complex-number-p n 'integerp)
 		  ;; float(log(n+m*%i)).
-		  (let ((re ($realpart n))
-			(im ($imagpart n)))
+		  (destructuring-bind (re . im) (trisplit n)
 		    (to (or (try-float-computation #'(lambda ()
 						       (log (complex (float re)
 								     (float im)))))
@@ -1282,11 +1279,12 @@
 		  ;;
 		  ;; where s = lcm(d1, d2), n and m are integers
 		  ;;
-		  (let* ((s (lcm ($denom ($realpart n))
-				 ($denom ($imagpart n))))
-			 (p ($expand (mul s n))))
+          (destructuring-bind (re . im) (trisplit n)
+		   (let* ((s (lcm ($denom re)
+			 	  ($denom im)))
+			      (p ($expand (mul s n))))
 		    (add ($float `((%log) ,s))
-			 ($float `((%log) ,p))))))))
+			 ($float `((%log) ,p)))))))))
 	((and (eq (caar e) '%erf)
 	      (eq (second e) '$%i))
 	 ;; Handle like erf(%i).  float(%i) (via recur-apply below)
