@@ -1,6 +1,6 @@
 ;;; -*-  Mode: Lisp; Package: Maxima; Syntax: Common-Lisp; Base: 10 -*- ;;;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;;;     The data in this file contains enhancments.                    ;;;;;
+;;;     The data in this file contains enhancements.                   ;;;;;
 ;;;                                                                    ;;;;;
 ;;;  Copyright (c) 1984,1987 by William Schelter,University of Texas   ;;;;;
 ;;;     All rights reserved                                            ;;;;;
@@ -15,18 +15,14 @@
 ;;; Macsyma error signalling. 
 ;;; 2:08pm  Tuesday, 30 June 1981 George Carrette.
 
-(defmvar $error `((mlist simp) "No error.")
-  "During an MAXIMA-ERROR break this is bound to a list
-  of the arguments to the call to MAXIMA-ERROR, with the message
-  text in a compact format.")
-
-(defmvar $errormsg 't
-  "If `false' then no maxima-error message is printed!")
-
 (defmfun $error (&rest l)
   "Signals a Maxima user error."
   (apply #'merror (fstringc l)))
 
+(defmfun $warning (&rest l)
+  "Signals a Maxima warning."
+  (apply #'mwarning l))
+
 (defmvar $error_size 60.
   "Expressions greater in SOME size measure over this value
   are replaced by symbols {ERREXP1, ERREXP2,...} in the MAXIMA-ERROR
@@ -35,12 +31,12 @@
   this variable may be determined by factors of terminal speed and type.")
 
 (defun error-size (exp)
-  ; RATDISREP the argument in case it's a CRE. Ugh.
-  ; But RATDISREP simplifies its argument, which is a no-no if we got here
+  ; Call SPECREPCHECK on the argument in case it's a specrep. Ugh.
+  ; But this simplifies its argument, which is a no-no if we got here
   ; because some simplification code is complaining, so inhibit simplification. Double ugh.
   (let (($simp nil))
     (declare (special $simp))
-    (setq exp (ratdisrep exp)))
+    (setq exp (specrepcheck exp)))
 
   (if (atom exp)
       0
@@ -60,7 +56,7 @@
 ;;; error variables. However, since we do bind the value of the
 ;;; variable $ERROR, calling the function $ERRORMSG will always
 ;;; set things back. It would be better to bind these variables,
-;;; for, amoung other things, then the values could get garbage 
+;;; for, among other things, then the values could get garbage
 ;;; collected.
 
 (define-condition maxima-$error (error)
@@ -71,34 +67,8 @@
 	     (let ((*standard-output* stream))
 	       ($errormsg)))))
 
-(defun merror (sstring &rest l)
-  (declare (special errcatch *mdebug*))
-  (setq $error `((mlist) ,sstring ,@ l))
-  (and $errormsg ($errormsg))
-  (cond (*mdebug*
-	 (let ((dispflag t) ret)
-	   (declare (special dispflag))
-	   (format t (intl:gettext " -- an error.  Entering the Maxima debugger.~%~
-                       Enter ':h' for help.~%"))
-	   (progn
-	     (setq ret (break-dbm-loop nil))
-	     (cond ((eql ret :resume)
-		    (break-quit))))))
-	(errcatch  (error 'maxima-$error))
-	(t
-	 (fresh-line *standard-output*)
-	 ($backtrace 3)
-	 (format t (intl:gettext "~& -- an error. To debug this try: debugmode(true);~%"))
-	 (force-output)
-	 (throw 'macsyma-quit 'maxima-error))))
-
-(defmacro with-$error (&body body)
-  "Let MERROR signal a MAXIMA-$ERROR condition."
-  `(let ((errcatch t)
-	 *mdebug*		       ;let merror signal a lisp error
-	 $errormsg)			;don't print $error
-     (declare (special errcatch *mdebug* $errormsg))
-     ,@body))
+(defvar *merror-signals-$error-p* nil
+  "When T, MERROR will signal a MAXIMA-$ERROR condition.")
 
 ;; Sample:
 ;; (defun h (he)
@@ -106,10 +76,56 @@
 ;; This will signal a MAXIMA-$ERROR condition:
 ;; (with-$error (h '$you))
 
-(defmvar $error_syms '((mlist) $errexp1 $errexp2 $errexp3)
-  "Symbols to bind the too-large `maxima-error' expresssions to")
+(defmacro with-$error (&body body)
+  "Let MERROR signal a MAXIMA-$ERROR condition."
+  `(let ((*merror-signals-$error-p* t))
+     (declare (special *merror-signals-$error-p*))
+     ,@body))
 
-(defun-prop ($error_syms assign) (var val)
+(defun merror (sstring &rest l)
+  (declare (special *quit-on-error*))
+  (setq $error `((mlist simp) ,sstring ,@ l))
+  (cond (*merror-signals-$error-p*
+	 (error 'maxima-$error))
+	((eq *mdebug* '$lisp)
+	 ; Go immediately into the lisp debugger
+	 (let ((*debugger-hook* nil))
+	   (invoke-debugger (make-condition 'maxima-$error))))
+	(*mdebug*
+	 (let ((dispflag t) ret)
+	   (declare (special dispflag))
+	   (when $errormsg
+	     ($errormsg))
+	   (format t (intl:gettext " -- an error.  Entering the Maxima debugger.~%~
+                       Enter ':h' for help.~%"))
+	   (progn
+	     (setq ret (break-dbm-loop nil))
+	     (cond ((eql ret :resume)
+		    (break-quit))))))
+	(errcatch
+	 (when $errormsg
+	   ($errormsg))
+	 (error 'maxima-$error))
+	(t
+	 (let ((*standard-output* *error-output*))
+	 (when $errormsg
+	   ($errormsg))
+	 (fresh-line *standard-output*)
+	 ($backtrace 3)
+	 (format *standard-output* (intl:gettext "~& -- an error. To debug this try: debugmode(true);~%"))
+	 (finish-output *standard-output*)
+         (if *quit-on-error* ($quit 1.))
+	 (throw 'macsyma-quit 'maxima-error)))))
+
+(defun mwarning (&rest l)
+ (let ((*print-base* 10))
+  (format *error-output* "Warning: ~{~a~^ ~}~%" (mapcar #'$sconcat l))))
+
+(defmvar $error_syms '((mlist) $errexp1 $errexp2 $errexp3)
+  "Symbols to bind the too-large `maxima-error' expressions to"
+  :properties ((assign 'assign-symbols)))
+
+(defun assign-symbols (var val)
   (if (not (and ($listp val)
 		(do ((l (cdr val) (cdr l)))
 		    ((null l) (return t))
@@ -152,7 +168,7 @@
   (let ((the-jig (process-error-argl (cddr $error))))
     (mapc #'(lambda (v x) (setf (symbol-value v) x)) (car the-jig) (cadr the-jig))
     (fresh-line)
-    (let ((errset nil))
+    (let ((errset nil) (*print-base* 10))
       (if (null (errset
 		 (apply #'mformat nil
 			(cadr $error) (caddr the-jig))))
@@ -162,14 +178,6 @@
     (fresh-line))
   '$done)
 
-(defmfun read-only-assign (var val)
-  (if munbindp
-      'munbindp
-      (merror (intl:gettext "assignment: attempting to assign read-only variable ~:M the value ~M") var val)))
-
-
-(defprop $error read-only-assign  assign)
-
 ;; RAT-ERROR (function)
 ;;
 ;; Throw to the nearest enclosing RAT-ERR tag (set by IGNORE-RAT-ERROR or
@@ -219,7 +227,7 @@
 ;;; This might also be done at code translation time.
 ;;; This is a bit crude.
 
-(defmfun fstringc (l)
+(defun fstringc (l)
   (do ((sl nil) (s) (sb)
        (se nil))
       ((null l)
